import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:flutter/cupertino.dart';
import 'package:nuntio_blocks/block_user.pb.dart';
import '../../nuntio_client.dart';

Future<User?> _getAuthState() async {
  var connectivityResult = await (Connectivity().checkConnectivity());
  if (connectivityResult == ConnectivityResult.none) {
    return null;
  }
  bool isAuthenticated = await NuntioClient.userBlock.isAuthenticated();
  if (isAuthenticated) {
    return NuntioClient.userBlock.getCurrentUser();
  }
  return null;
}

Widget AuthenticatedWidget(
    {required Function(User? user) builder,
    required Function ifNotAuthenticated}) {
  return FutureBuilder<User?>(
    future: _getAuthState(),
    builder: (BuildContext context, AsyncSnapshot<User?> snapshot) {
      switch (snapshot.connectionState) {
        case ConnectionState.waiting:
          return const Center(
            child: CupertinoActivityIndicator(),
          );
        case ConnectionState.done:
          if (snapshot.data != null) {
            return builder(snapshot.data);
          }
          ifNotAuthenticated();
          return CupertinoActivityIndicator();
        default:
          return Text("Error");
      }
    },
  );
}
